GABAAReceptor

Struct GABAAReceptor 

pub struct GABAAReceptor {
    pub open_probability: f64,
    pub tau_rise: f64,
    pub tau_decay: f64,
    pub alpha: f64,
    pub beta: f64,
    pub e_rev: f64,
    pub g_max: f64,
    /* private fields */
}
GABA-A receptor - fast inhibitory receptor.

GABA-A receptors are ionotropic chloride channels that mediate fast inhibitory transmission with time constants similar to AMPA receptors.

Fields

open_probability: f64

Open probability (0 to 1).

tau_rise: f64

Rise time constant (ms).

tau_decay: f64

Decay time constant (ms).

alpha: f64

Forward binding rate (1/(mM·ms)).

beta: f64

Unbinding rate (1/ms).

e_rev: f64

Reversal potential (mV) - depends on Cl- gradient.

g_max: f64

Maximum conductance (nS).

Implementations

Source

impl GABAAReceptor

pub fn new() -> Self

Create a new GABA-A receptor with default parameters.

pub fn current(&self, voltage: f64) -> f64

Get the synaptic current (pA).